package com.bsoft.admin.service.impl;

import com.bsoft.admin.common.enums.StateType;
import com.bsoft.admin.mapper.DicOrgMapper;
import com.bsoft.admin.mapper.SysUserOrgRsMapper;
import com.bsoft.admin.model.DicOrg;
import com.bsoft.admin.model.SysUserOrgRs;
import com.bsoft.admin.model.reqmodel.OrgReq;
import com.bsoft.admin.model.respmodel.DicOrgList;
import com.bsoft.admin.service.DicOrgService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class DicOrgServiceImpl implements DicOrgService {
    @Resource
    private DicOrgMapper dicOrgMapper;
    @Resource
    private SysUserOrgRsMapper sysUserOrgRsMapper;

    private List<DicOrgList> getLevelData(List<DicOrgList> list, Long parentcode) {
        List<DicOrgList> resultList = new ArrayList<>();
        for (DicOrgList data : list) {
            if (data.getParentId() == parentcode){
                List<DicOrgList> childList = getLevelData(list,data.getId());
                data.setDicOrgList(childList);
                resultList.add(data);
            }
        }
        return resultList;
    }


    public List<DicOrgList> getAll(OrgReq.GetOrgReq org){
        List<DicOrgList> list = dicOrgMapper.selectParentAll();
        if(org.getOrgName()!=null){
            list = list.stream().filter(
                    o->(o.getOrgName()!=null && o.getOrgName().toLowerCase().contains(org.getOrgName().toLowerCase())))
                    .collect(Collectors.toList());
        }
        List<DicOrgList> resultList  = getLevelData(list, Long.valueOf(ORG_TOP_PARENT_ID));
        return resultList;
    }

    public DicOrg info(Long orgId){
        DicOrg dicOrg = dicOrgMapper.selectByPrimaryKey(orgId);
        return dicOrg;
    }

    public boolean addOrg(Long userId,OrgReq.AddOrgReq org){
        if(org!=null){
            DicOrg dicOrg = new DicOrg();
            dicOrg.setCreateDate(new Date());
            dicOrg.setCreateUserid(userId);
            dicOrg.setState((short) StateType.ON.getValue());
            dicOrg.setOrgCode(org.getOrgCode());
            dicOrg.setOrgName(org.getOrgName());
            dicOrg.setOrgShortName(org.getOrgShortName());
            dicOrg.setOrgGroup(org.getOrgGroup());
            dicOrg.setOrgType(org.getOrgType());
            dicOrg.setOrgAddress(org.getOrgAddress());
            dicOrg.setParentId(org.getParentId());
            dicOrgMapper.insert(dicOrg);
            return true;
        }
        return false;
    }

    public boolean deleteOrg(OrgReq.DeleteOrgReq org){
        if(org!=null){
            DicOrg dicOrg = dicOrgMapper.selectByPrimaryKey(org.getOrgId());
            if(dicOrg!=null){
                dicOrg.setState((short) StateType.OFF.getValue());
                dicOrgMapper.updateByPrimaryKey(dicOrg);
                return true;
            }
        }
        return false;
    }

    public boolean updateOrg(OrgReq.UpdateOrgReq org){
        if(org!=null) {
            DicOrg dicOrg = dicOrgMapper.selectByPrimaryKey(org.getOrgId());
            if(dicOrg!=null){
                dicOrg.setOrgCode(org.getOrgCode());
                dicOrg.setOrgName(org.getOrgName());
                dicOrg.setOrgShortName(org.getOrgShortName());
                dicOrg.setOrgGroup(org.getOrgGroup());
                dicOrg.setOrgType(org.getOrgType());
                dicOrg.setOrgAddress(org.getOrgAddress());
                dicOrg.setParentId(org.getParentId());
                dicOrgMapper.updateByPrimaryKey(dicOrg);
                return true;
            }
        }
        return false;
    }

    public DicOrg getByName(String orgName){
        return dicOrgMapper.selectByName(orgName);
    }

    /**
     * 查询用户机构
     * @param userId 操作人ID
     * @return
     */
    @Override
    public SysUserOrgRs getUserOrg(Long userId){
        SysUserOrgRs sysUserOrgRs = sysUserOrgRsMapper.selectByUser(userId);
        return sysUserOrgRs;
    }

    @Override
    public boolean saveUserOrg(Long userId,OrgReq.SaveUserOrgReq org){
        if(org!=null&&org.getOrgId()!=null&&org.getUserId()!=null){
            int result = 0;
            //判断是否存在关系数据
            SysUserOrgRs sysUserOrgRs = sysUserOrgRsMapper.selectByUser(org.getUserId());
            if(sysUserOrgRs!=null){
                //修改
                sysUserOrgRs.setOrgId(org.getOrgId());
                result = sysUserOrgRsMapper.updateByPrimaryKey(sysUserOrgRs);

            }else{
                //添加
                sysUserOrgRs = new SysUserOrgRs();
                sysUserOrgRs.setOrgId(org.getOrgId());
                sysUserOrgRs.setUserId(org.getUserId());
                sysUserOrgRs.setCreateDate(new Date());
                sysUserOrgRs.setCreateUserid(userId);
                sysUserOrgRs.setState((short) StateType.ON.getValue());
                result = sysUserOrgRsMapper.insert(sysUserOrgRs);
            }
            return result>0;
        }
        return false;
    }



}
