package com.bsoft.admin.service.impl;

import com.bsoft.admin.common.enums.StateType;
import com.bsoft.admin.mapper.SysRoleMapper;
import com.bsoft.admin.mapper.SysUserRoleRsMapper;
import com.bsoft.admin.model.SysRole;
import com.bsoft.admin.model.SysUserRoleRs;
import com.bsoft.admin.model.reqmodel.RoleReq;
import com.bsoft.admin.service.SysRoleService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class SysRoleServiceImpl implements SysRoleService {
    @Resource
    private SysRoleMapper sysRoleMapper;
    @Resource
    private SysUserRoleRsMapper sysUserRoleRsMapper;

    @Override
    public SysRole findByCode(Long roleCode) {
        return sysRoleMapper.selectByCode(roleCode);
    }

    @Override
    public boolean addRole(Long userId, RoleReq.AddRoleReq role) {
        if(role!=null){
        SysRole sysRole = new SysRole();
            sysRole.setCreateDate(new Date());
            sysRole.setCreateUserid(userId);
            sysRole.setState((short) StateType.ON.getValue());
            sysRole.setRoleCode(role.getRoleCode());
            sysRole.setRoleName(role.getRoleName());
            sysRoleMapper.insert(sysRole);
            return true;
        }
        return false;
    }

    @Override
    public boolean deleteRole(RoleReq.DeleteRoleReq role) {
        if(role!=null){
            SysRole sysRole = sysRoleMapper.selectByPrimaryKey(role.getRoleId());
            if(sysRole!=null){
                sysRole.setState((short) StateType.OFF.getValue());
                sysRoleMapper.updateByPrimaryKey(sysRole);
                return true;
            }
        }
        return false;
    }

    @Override
    public boolean updateRole(RoleReq.UpdateRoleReq role) {
        if(role!=null) {
            SysRole sysRole = sysRoleMapper.selectByPrimaryKey(role.getRoleId());
            if(sysRole!=null){
                sysRole.setRoleCode(role.getRoleCode());
                sysRole.setRoleName(role.getRoleName());
                sysRoleMapper.updateByPrimaryKey(sysRole);
                return true;
            }
        }
        return false;
    }

    @Override
    public List<SysRole> getAll(RoleReq.GetRoleReq role) {
        List<SysRole> list = sysRoleMapper.selectAll();
        if(role.getRoleName()!=null){
            list = list.stream().filter(
                    o->(o.getRoleName()!=null && o.getRoleName().toLowerCase().contains(role.getRoleName().toLowerCase())))
                    .collect(Collectors.toList());
        }
        return list;
    }

    @Override
    public SysRole info(Long roleId) {
        SysRole sysRole = sysRoleMapper.selectByPrimaryKey(roleId);
        return sysRole;
    }

    @Override
    public boolean saveUserRole(Long userId,RoleReq.SavaUserRoleReq role){
        if(role!=null&&role.getRoleId()!=null&&role.getUserId()!=null){
            SysUserRoleRs info = new SysUserRoleRs();
            info.setCreateDate(new Date());
            info.setCreateUserid(userId);
            info.setState((short)StateType.ON.getValue());
            info.setUserId(role.getUserId());
            info.setRoleId(role.getRoleId());
            sysUserRoleRsMapper.insert(info);
            return true;
        }
        return false;
    }
}
